
# TFit

TFit :  Assessing the combinatorial potential of Transcription Factors in Gene Regulation

# Usage

## Installation 

Use `poetry add tfitpy@^0.0.6 --python ">=3.11,<3.14.1 || >3.14.1,<4.0"` if facing version issues

## Initial setup




# Development setup

## Clone

## Accessing the CLI

`poetry run tfit --help`




